==> openshift-model-console-5.10.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsoleQuickStartTaskFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent<A>{
  public ConsoleQuickStartTaskFluentImpl() {
  }
  public ConsoleQuickStartTaskFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTask instance) {
    this.withDescription(instance.getDescription()); 
    this.withReview(instance.getReview()); 
    this.withSummary(instance.getSummary()); 
    this.withTitle(instance.getTitle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String description;
  private io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder review;
  private io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder summary;
  private java.lang.String title;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildReview instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview getReview() {
    return this.review!=null?this.review.build():null;
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview buildReview() {
    return this.review!=null?this.review.build():null;
  }
  public A withReview(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview review) {
    _visitables.get("review").remove(this.review);
    if (review!=null){ this.review= new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder(review); _visitables.get("review").add(this.review);} return (A) this;
  }
  public java.lang.Boolean hasReview() {
    return this.review != null;
  }
  public A withNewReview(java.lang.String failedTaskHelp,java.lang.String instructions) {
    return (A)withReview(new ConsoleQuickStartTaskReview(failedTaskHelp, instructions));
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> withNewReview() {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluentImpl.ReviewNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> withNewReviewLike(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview item) {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluentImpl.ReviewNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> editReview() {
    return withNewReviewLike(getReview());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> editOrNewReview() {
    return withNewReviewLike(getReview() != null ? getReview(): new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder().build());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> editOrNewReviewLike(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview item) {
    return withNewReviewLike(getReview() != null ? getReview(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSummary instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary getSummary() {
    return this.summary!=null?this.summary.build():null;
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary buildSummary() {
    return this.summary!=null?this.summary.build():null;
  }
  public A withSummary(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary summary) {
    _visitables.get("summary").remove(this.summary);
    if (summary!=null){ this.summary= new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder(summary); _visitables.get("summary").add(this.summary);} return (A) this;
  }
  public java.lang.Boolean hasSummary() {
    return this.summary != null;
  }
  public A withNewSummary(java.lang.String failed,java.lang.String success) {
    return (A)withSummary(new ConsoleQuickStartTaskSummary(failed, success));
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> withNewSummary() {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluentImpl.SummaryNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> withNewSummaryLike(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary item) {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluentImpl.SummaryNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> editSummary() {
    return withNewSummaryLike(getSummary());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> editOrNewSummary() {
    return withNewSummaryLike(getSummary() != null ? getSummary(): new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder().build());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> editOrNewSummaryLike(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary item) {
    return withNewSummaryLike(getSummary() != null ? getSummary(): item);
  }
  public java.lang.String getTitle() {
    return this.title;
  }
  public A withTitle(java.lang.String title) {
    this.title=title; return (A) this;
  }
  public java.lang.Boolean hasTitle() {
    return this.title != null;
  }
  
  /**
   * Method is deprecated. use withTitle instead.
   */
  @java.lang.Deprecated
  public A withNewTitle(java.lang.String arg0) {
    return (A)withTitle(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleQuickStartTaskFluentImpl that = (ConsoleQuickStartTaskFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (review != null ? !review.equals(that.review) :that.review != null) return false;
    if (summary != null ? !summary.equals(that.summary) :that.summary != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  review,  summary,  title,  additionalProperties,  super.hashCode());
  }
  public class ReviewNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<N>> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ReviewNestedImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview item) {
      this.builder = new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder(this, item);
    }
    ReviewNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder builder;
    public N and() {
      return (N) ConsoleQuickStartTaskFluentImpl.this.withReview(builder.build());
    }
    public N endReview() {
      return and();
    }
    
  }
  public class SummaryNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<N>> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SummaryNestedImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary item) {
      this.builder = new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder(this, item);
    }
    SummaryNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder builder;
    public N and() {
      return (N) ConsoleQuickStartTaskFluentImpl.this.withSummary(builder.build());
    }
    public N endSummary() {
      return and();
    }
    
  }
  
}

==> openshift-model-console-5.12.4-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsoleQuickStartTaskFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent<A>{
  public ConsoleQuickStartTaskFluentImpl() {
  }
  public ConsoleQuickStartTaskFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTask instance) {
    this.withDescription(instance.getDescription()); 
    this.withReview(instance.getReview()); 
    this.withSummary(instance.getSummary()); 
    this.withTitle(instance.getTitle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String description;
  private io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder review;
  private io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder summary;
  private java.lang.String title;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildReview instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview getReview() {
    return this.review!=null?this.review.build():null;
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview buildReview() {
    return this.review!=null?this.review.build():null;
  }
  public A withReview(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview review) {
    _visitables.get("review").remove(this.review);
    if (review!=null){ this.review= new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder(review); _visitables.get("review").add(this.review);} return (A) this;
  }
  public java.lang.Boolean hasReview() {
    return this.review != null;
  }
  public A withNewReview(java.lang.String failedTaskHelp,java.lang.String instructions) {
    return (A)withReview(new ConsoleQuickStartTaskReview(failedTaskHelp, instructions));
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> withNewReview() {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluentImpl.ReviewNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> withNewReviewLike(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview item) {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluentImpl.ReviewNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> editReview() {
    return withNewReviewLike(getReview());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> editOrNewReview() {
    return withNewReviewLike(getReview() != null ? getReview(): new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder().build());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<A> editOrNewReviewLike(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview item) {
    return withNewReviewLike(getReview() != null ? getReview(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSummary instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary getSummary() {
    return this.summary!=null?this.summary.build():null;
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary buildSummary() {
    return this.summary!=null?this.summary.build():null;
  }
  public A withSummary(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary summary) {
    _visitables.get("summary").remove(this.summary);
    if (summary!=null){ this.summary= new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder(summary); _visitables.get("summary").add(this.summary);} return (A) this;
  }
  public java.lang.Boolean hasSummary() {
    return this.summary != null;
  }
  public A withNewSummary(java.lang.String failed,java.lang.String success) {
    return (A)withSummary(new ConsoleQuickStartTaskSummary(failed, success));
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> withNewSummary() {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluentImpl.SummaryNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> withNewSummaryLike(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary item) {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluentImpl.SummaryNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> editSummary() {
    return withNewSummaryLike(getSummary());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> editOrNewSummary() {
    return withNewSummaryLike(getSummary() != null ? getSummary(): new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder().build());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<A> editOrNewSummaryLike(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary item) {
    return withNewSummaryLike(getSummary() != null ? getSummary(): item);
  }
  public java.lang.String getTitle() {
    return this.title;
  }
  public A withTitle(java.lang.String title) {
    this.title=title; return (A) this;
  }
  public java.lang.Boolean hasTitle() {
    return this.title != null;
  }
  
  /**
   * Method is deprecated. use withTitle instead.
   */
  @java.lang.Deprecated
  public A withNewTitle(java.lang.String arg0) {
    return (A)withTitle(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleQuickStartTaskFluentImpl that = (ConsoleQuickStartTaskFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (review != null ? !review.equals(that.review) :that.review != null) return false;
    if (summary != null ? !summary.equals(that.summary) :that.summary != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  review,  summary,  title,  additionalProperties,  super.hashCode());
  }
  public class ReviewNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<N>> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.ReviewNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ReviewNestedImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview item) {
      this.builder = new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder(this, item);
    }
    ReviewNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewBuilder builder;
    public N and() {
      return (N) ConsoleQuickStartTaskFluentImpl.this.withReview(builder.build());
    }
    public N endReview() {
      return and();
    }
    
  }
  public class SummaryNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<N>> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskFluent.SummaryNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SummaryNestedImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary item) {
      this.builder = new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder(this, item);
    }
    SummaryNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryBuilder builder;
    public N and() {
      return (N) ConsoleQuickStartTaskFluentImpl.this.withSummary(builder.build());
    }
    public N endSummary() {
      return and();
    }
    
  }
  
}
